{% extends 'generic/object.html' %}
{% load humanize %}
{% load helpers %}
{% load plugins %}

{% block content %}
<div class="row">
  <div class="col col-md-6">
      {% plugin_left_page object %}
  </div>
  <div class="col col-md-6">
    {% include 'inc/panels/related_objects.html' %}
    {% include 'inc/panels/custom_fields.html' %}
    {% include 'inc/panels/comments.html' %}
    {% include 'inc/panels/tags.html' %}
    {% plugin_right_page object %}
  </div>
</div>
<div class="row">
    <div class="col col-md-12">
        {% plugin_full_width_page object %}
    </div>
</div>
{% endblock %}